==> jboss-eap-7.3.5-src.zip: jboss-eap-7.3-src/clustering/ejb/spi/src/main/java/org/wildfly/clustering/ejb/BeanManagerFactoryServiceConfiguratorFactory.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.ejb;

import org.jboss.as.clustering.controller.CapabilityServiceConfigurator;
import org.jboss.msc.service.ServiceName;

public interface BeanManagerFactoryServiceConfiguratorFactory {

    /**
     * Installs dependencies for a deployment unit
     * @param name the service name of the deployment unit
     */
    Iterable<CapabilityServiceConfigurator> getDeploymentServiceConfigurators(ServiceName name);

    /**
     * Builds a bean manager factory for an EJB within a deployment.
     * @param context the bean context
     * @return a service builder
     */
    CapabilityServiceConfigurator getBeanManagerFactoryServiceConfigurator(BeanContext context);
}

==> jboss-eap-7.4.9-src.zip: jboss-eap-7.4-src/clustering/ejb/spi/src/main/java/org/wildfly/clustering/ejb/BeanManagerFactoryServiceConfiguratorFactory.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.ejb;

import org.jboss.as.clustering.controller.CapabilityServiceConfigurator;
import org.jboss.msc.service.ServiceName;

public interface BeanManagerFactoryServiceConfiguratorFactory {

    /**
     * Installs dependencies for a deployment unit
     * @param name the service name of the deployment unit
     */
    Iterable<CapabilityServiceConfigurator> getDeploymentServiceConfigurators(ServiceName name);

    /**
     * Builds a bean manager factory for an Jakarta Enterprise Beans within a deployment.
     * @param context the bean context
     * @return a service builder
     */
    CapabilityServiceConfigurator getBeanManagerFactoryServiceConfigurator(BeanContext context);
}
